# Import necessary modules
from machine import Pin 
import bluetooth
from ble_simple_peripheral import BLESimplePeripheral
import utime

# Create a Bluetooth Low Energy (BLE) object
ble = bluetooth.BLE()

# Create an instance of the BLESimplePeripheral class with the BLE object
sp = BLESimplePeripheral(ble)

# Create a Pin object for the onboard LED, configure it as an output
led = Pin("LED", Pin.OUT)

# Initialize the LED state to 0 (off)
led.value(1) # 최초 led 켜짐으로 연결 확인
led_state = 0
m1 = Pin(1, Pin.OUT)
m2 = Pin(2, Pin.OUT)
m3 = Pin(3, Pin.OUT)
m4 = Pin(4, Pin.OUT)
 
en1 = Pin(0, Pin.OUT)
en2 = Pin(5, Pin.OUT)
en1(1)  # motor 1 enable, set value 0 to disable
en2(1)  # motor 2 enable, set value 0 to disable

# Define a callback function to handle received data
def on_rx(data):
    print("Data received: ", data)  # Print the received data
    global led_state  # Access the global variable led_state
    if data == b'led\r\n':  # Check if the received data is "toggle"
        led.value(not led_state)  # Toggle the LED state (on/off)
        led_state = 1 - led_state  # Update the LED state
    elif data == b'go\r\n':
        m1(1)
        m2(0)
        m3(0)
        m4(1)
        utime.sleep(1)
    elif data == b'stop\r\n':
        m1(0)
        m2(0)
        m3(0)
        m4(0)
        utime.sleep(1)
    elif data == b'right\r\n':
        m1(1)
        m2(0)
        m3(0)
        m4(0)
        utime.sleep(1)
    elif data == b'left\r\n':
        m1(0)
        m2(0)
        m3(0)
        m4(1)
        utime.sleep(1)
    elif data == b'back\r\n':
        m1(0)
        m2(1)
        m3(1)
        m4(0)
        utime.sleep(1)

# Start an infinite loop
while True:
    if sp.is_connected():  # Check if a BLE connection is established
        sp.on_write(on_rx)  # Set the callback function for data reception
